@@ -93,6 +93,10 @@ impl App {
     pub fn event(&mut self, ev: Event) {
         trace!("event: {:?}", ev);
 
+        if self.check_quit(ev) {
+            return;
+        }
+
         let mut flags = NeedsUpdate::empty();
 
         if event_pump(ev, self.components_mut().as_mut_slice()) {
@@ -110,8 +114,6 @@ impl App {
             flags.insert(new_flags);
         }
 
-        self.check_quit(ev);
-
         let new_flags = self.process_queue();
         flags.insert(new_flags);
 
@@ -163,12 +165,14 @@ impl App {
 impl App {
     accessors!(self, [msg, reset, commit, help, revlog, status_tab]);
 
-    fn check_quit(&mut self, ev: Event) {
+    fn check_quit(&mut self, ev: Event) -> bool {
         if let Event::Key(e) = ev {
             if let keys::EXIT = e {
                 self.do_quit = true;
+                return true;
             }
         }
+        false
     }
 
     fn toggle_tabs(&mut self) {
@@ -216,13 +220,17 @@ impl App {
                     if sync::reset_workdir_folder(
                         CWD,
                         reset_item.path.as_str(),
-                    ) {
+                    )
+                    .is_ok()
+                    {
                         flags.insert(NeedsUpdate::ALL);
                     }
                 } else if sync::reset_workdir_file(
                     CWD,
                     reset_item.path.as_str(),
-                ) {
+                )
+                .is_ok()
+                {
                     flags.insert(NeedsUpdate::ALL);
                 }
             }
@@ -235,10 +243,14 @@ impl App {
                     self.status_tab.selected_path()
                 {
                     if is_stage {
-                        if sync::unstage_hunk(CWD, path, hash) {
+                        if sync::unstage_hunk(CWD, path, hash)
+                            .unwrap()
+                        {
                             flags.insert(NeedsUpdate::ALL);
                         }
-                    } else if sync::stage_hunk(CWD, path, hash) {
+                    } else if sync::stage_hunk(CWD, path, hash)
+                        .is_ok()
+                    {
                         flags.insert(NeedsUpdate::ALL);
                     }
                 }
@@ -327,7 +339,7 @@ impl App {
     ) {
         let splitter = Text::Styled(
             Cow::from(strings::CMD_SPLITTER),
-            Style::default().bg(Color::Black),
+            Style::default(),
         );
 
         let style_enabled =
